aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureRequest.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureRequest.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureRequest.java38
1 files changed, 19 insertions, 19 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureRequest.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureRequest.java
index 32a378e..3e07c51 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureRequest.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureRequest.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,26 +10,26 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlRootElement;
+import jakarta.xml.bind.annotation.XmlType;
/**
- * <p>Java class for anonymous complex type.
+ * <p>Java-Klasse für anonymous complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType>
- * &lt;complexContent>
- * &lt;extension base="{http://reference.e-government.gv.at/namespace/moa/20020822#}VerifyCMSSignatureRequestType">
- * &lt;attribute name="Signatories" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}SignatoriesType" default="1" />
- * &lt;/extension>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType&gt;
+ * &lt;complexContent&gt;
+ * &lt;extension base="{http://reference.e-government.gv.at/namespace/moa/20020822#}VerifyCMSSignatureRequestType"&gt;
+ * &lt;attribute name="Signatories" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}SignatoriesType" default="1" /&gt;
+ * &lt;/extension&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -50,7 +50,7 @@ public class VerifyCMSSignatureRequest
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the signatories property.
*
* <p>
@@ -50,7 +50,7 @@ public class VerifyCMSSignatureRequest
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the signatories property.
*